@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2018-2023 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2018-2025 <tsujan2000@gmail.com>
  *
  * Arqiver is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -91,7 +91,7 @@ Backend::~Backend() {
 
 void Backend::setTarCommand(const QString& cmnd) {
 #ifdef Q_OS_LINUX
-  Q_UNUSED(cmnd);
+  Q_UNUSED(cmnd)
   tarCmnd_ = TAR_CMD;
 #else
   if (cmnd.isEmpty())
@@ -165,7 +165,7 @@ void Backend::loadFile(const QString& path, bool withPassword) {
            || mt == "application/x-cd-image" || mt == "application/vnd.efi.iso" || mt == "application/vnd.appimage"
            || mt == "application/x-xz"
            || mt == "application/zstd"
-           || mt == "application/x-ace"
+           //|| mt == "application/x-ace"
            || mt == "application/x-bzip" || mt == "application/x-bzip1" || mt == "application/x-bzip2" || mt == "application/x-bzpdf" || mt == "application/x-xzpdf"
            || mt == "application/x-apple-diskimage") {
     is7z_ = true; isGzip_ = false;
@@ -212,15 +212,15 @@ bool Backend::canModify(bool *canUpdate) const {
   if (validMimeTypes.isEmpty()) {
     validMimeTypes << "application/zip" << "application/x-compressed-tar" << "application/x-gzpdf" << "image/svg+xml-compressed" << "application/x-xz-compressed-tar" << "application/x-bzip-compressed-tar" << "application/x-bzip1-compressed-tar" << "application/x-bzip2-compressed-tar" << "application/x-tar" << "application/x-lzma-compressed-tar" << "application/x-zstd-compressed-tar" << "application/x-cpio" << /*".pax" <<*/ "application/x-archive" << /*".shar" <<*/ "application/gzip" << "application/x-7z-compressed";
   }
-  static QStringList updatedMimeTypes;
-  if (updatedMimeTypes.isEmpty()) {
-    updatedMimeTypes << "application/zstd" << "application/x-bzip" << "application/x-bzip1" << "application/x-bzip2" << "application/x-xz" << "application/vnd.debian.binary-package" << "application/x-rpm" << "application/x-source-rpm";
+  static QStringList updatableMimeTypes;
+  if (updatableMimeTypes.isEmpty()) {
+    updatableMimeTypes << /*"application/zstd" << */"application/x-bzip" << "application/x-bzip1" << "application/x-bzip2" << "application/x-xz" << "application/vnd.debian.binary-package" << "application/x-rpm" << "application/x-source-rpm";
   }
   QMimeDatabase mimeDatabase;
   QString mimeTypeName = mimeDatabase.mimeTypeForFile(QFileInfo(filepath_)).name();
   bool res = archiveSingleRoot_ != "."  // not like some rpm archives
              && validMimeTypes.contains(mimeTypeName);
-  *canUpdate = (archiveSingleRoot_ != "." && (res || updatedMimeTypes.contains(mimeTypeName)));
+  *canUpdate = (archiveSingleRoot_ != "." && (res || updatableMimeTypes.contains(mimeTypeName)));
   return res;
 }
 
@@ -288,8 +288,7 @@ static inline void skipExistingFiles(QString& file) {
 
 // This is only for bsdtar, which uses an ed-like pattern substitution.
 // WARNING: Here it is supposed that backslashes are escaped by bsdtar.
-static inline QString escapeSpecialChars(const QString& str)
-{
+static inline QString escapeSpecialChars(const QString& str) {
   QString newStr = str;
   newStr.replace("*", "\\*").replace("[", "\\[").replace("^", "\\^")
         .replace("$", "\\$").replace("?", "\\?");
@@ -349,8 +348,7 @@ void Backend::updateArchive() {
   args << "-c" << "-a";
   skipExistingFiles(tmpfilepath_); // practically not required
   args << "-f" << tmpfilepath_;
-  for (const QString &str : std::as_const(changedFiles_))
-  {
+  for (const QString &str : std::as_const(changedFiles_)) {
     /* WARNING: Since the workaround for bsdtar's escaped backslashes is already applied,
                 they need to be escaped again, before other special characters are escaped. */
     args << "--exclude" << "^" + escapeSpecialChars(str.section('/', 3).replace("\\", "\\\\"));
@@ -1001,8 +999,7 @@ void Backend::extractTempFiles(const QStringList& paths) {
   }
 
   // files may be edited also by drag-and-drop
-  for (const QString &str : std::as_const(tempFileNames))
-  {
+  for (const QString &str : std::as_const(tempFileNames)) {
     QFileInfo info(str);
     if (!info.isDir()) {
       const QString finalTarget = info.canonicalFilePath();
