@@ -4,7 +4,7 @@
 <context>
     <name>Arqiver::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="156"/>
+        <location filename="../../about.ui" line="160"/>
         <source>License</source>
         <translation>Licenza</translation>
     </message>
@@ -12,43 +12,43 @@
 <context>
     <name>Arqiver::Backend</name>
     <message>
-        <location filename="../../backends.cpp" line="842"/>
+        <location filename="../../backends.cpp" line="840"/>
         <source>This file is a link but its target does not exist.</source>
         <translation>Questo file è un collegamento a un altro file inesistente.</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1264"/>
-        <location filename="../../backends.cpp" line="1296"/>
-        <location filename="../../backends.cpp" line="1340"/>
+        <location filename="../../backends.cpp" line="1261"/>
+        <location filename="../../backends.cpp" line="1293"/>
+        <location filename="../../backends.cpp" line="1337"/>
         <source>Could not read archive</source>
         <translation>Impossibile leggere l&apos;archivio</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1299"/>
-        <location filename="../../backends.cpp" line="1345"/>
+        <location filename="../../backends.cpp" line="1296"/>
+        <location filename="../../backends.cpp" line="1342"/>
         <source>Archive Loaded</source>
         <translation>Archivio Caricato</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1306"/>
-        <location filename="../../backends.cpp" line="1393"/>
+        <location filename="../../backends.cpp" line="1303"/>
+        <location filename="../../backends.cpp" line="1390"/>
         <source>Modification Finished</source>
         <translation>Modifica Terminata</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1327"/>
-        <location filename="../../backends.cpp" line="1362"/>
+        <location filename="../../backends.cpp" line="1324"/>
+        <location filename="../../backends.cpp" line="1359"/>
         <source>Extraction Finished</source>
         <translation>Estrazione Terminata</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1330"/>
-        <location filename="../../backends.cpp" line="1381"/>
+        <location filename="../../backends.cpp" line="1327"/>
+        <location filename="../../backends.cpp" line="1378"/>
         <source>Extraction Failed</source>
         <translation>Estrazione Non Riuscita</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1478"/>
+        <location filename="../../backends.cpp" line="1475"/>
         <source>%1 is missing from your system.
 Please install it for this kind of archive!</source>
         <translation>%1 non è presente nel tuo sistema.
@@ -288,321 +288,316 @@ l&apos;eseguibile non è incluso in libarchive.</translation>
         <translation>Aggiorna archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="145"/>
+        <location filename="../../mainWin.cpp" line="147"/>
         <source>Root</source>
         <translation>Radice</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="250"/>
+        <location filename="../../mainWin.cpp" line="252"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="321"/>
+        <location filename="../../mainWin.cpp" line="323"/>
         <source>File</source>
         <translation>File</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="321"/>
+        <location filename="../../mainWin.cpp" line="323"/>
         <source>MimeType</source>
         <translation>Tipo MIME</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="321"/>
+        <location filename="../../mainWin.cpp" line="323"/>
         <source>Size</source>
         <translation>Dimensione</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="551"/>
-        <location filename="../../mainWin.cpp" line="836"/>
-        <location filename="../../mainWin.cpp" line="880"/>
+        <location filename="../../mainWin.cpp" line="553"/>
+        <location filename="../../mainWin.cpp" line="838"/>
+        <location filename="../../mainWin.cpp" line="882"/>
         <source>Opening Archive...</source>
         <translation>Apertura Archivio...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="765"/>
+        <location filename="../../mainWin.cpp" line="767"/>
         <source>Create Archive</source>
         <translation>Crea Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="462"/>
-        <location filename="../../mainWin.cpp" line="791"/>
-        <location filename="../../mainWin.cpp" line="990"/>
-        <location filename="../../mainWin.cpp" line="1299"/>
+        <location filename="../../mainWin.cpp" line="464"/>
+        <location filename="../../mainWin.cpp" line="793"/>
+        <location filename="../../mainWin.cpp" line="992"/>
+        <location filename="../../mainWin.cpp" line="1300"/>
         <source>Question</source>
         <translation>Richiesta</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="792"/>
+        <location filename="../../mainWin.cpp" line="794"/>
         <source>The following archive already exists:</source>
         <translation>Il seguente archivio esiste già:</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="794"/>
+        <location filename="../../mainWin.cpp" line="796"/>
         <source>Do you want to replace it?
 </source>
         <translation>Vuoi sostituirlo?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="828"/>
+        <location filename="../../mainWin.cpp" line="830"/>
         <source>Open Archive</source>
         <translation>Apri Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="895"/>
-        <location filename="../../mainWin.cpp" line="902"/>
-        <location filename="../../mainWin.cpp" line="939"/>
+        <location filename="../../mainWin.cpp" line="897"/>
+        <location filename="../../mainWin.cpp" line="904"/>
+        <location filename="../../mainWin.cpp" line="941"/>
         <source>Add to Archive</source>
         <translation>Aggiungi ad Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="934"/>
-        <location filename="../../mainWin.cpp" line="965"/>
-        <location filename="../../mainWin.cpp" line="1250"/>
-        <location filename="../../mainWin.cpp" line="1256"/>
+        <location filename="../../mainWin.cpp" line="936"/>
+        <location filename="../../mainWin.cpp" line="967"/>
+        <location filename="../../mainWin.cpp" line="1252"/>
+        <location filename="../../mainWin.cpp" line="1258"/>
         <source>Adding Items...</source>
         <translation>Aggiungo elementi...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="991"/>
+        <location filename="../../mainWin.cpp" line="993"/>
         <source>Do you want to remove the selected item(s)?
 </source>
         <translation>Vuoi rimuovere gli elementi selezionati?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1010"/>
+        <location filename="../../mainWin.cpp" line="1012"/>
         <source>Removing Items...</source>
         <translation>Rimuovo Elementi...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1213"/>
-        <location filename="../../mainWin.cpp" line="1228"/>
-        <location filename="../../mainWin.cpp" line="1314"/>
-        <location filename="../../mainWin.cpp" line="1328"/>
+        <location filename="../../mainWin.cpp" line="1215"/>
+        <location filename="../../mainWin.cpp" line="1230"/>
+        <location filename="../../mainWin.cpp" line="1315"/>
+        <location filename="../../mainWin.cpp" line="1329"/>
         <source>Extracting...</source>
         <translation>Estrazione...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1054"/>
+        <location filename="../../mainWin.cpp" line="1056"/>
         <source>Copy Archive Path</source>
         <translation>Copia Percorso Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="463"/>
+        <location filename="../../mainWin.cpp" line="465"/>
         <source>Some files have been modified.</source>
         <translation>Alcuni file sono stati modificati.</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="464"/>
+        <location filename="../../mainWin.cpp" line="466"/>
         <source>Do you want to ignore the changes?
 </source>
         <translation>Ignorare i cambiamenti?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="625"/>
+        <location filename="../../mainWin.cpp" line="627"/>
         <source>All Types</source>
         <translation>Tutti I Tipi</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="635"/>
-        <location filename="../../mainWin.cpp" line="659"/>
+        <location filename="../../mainWin.cpp" line="637"/>
+        <location filename="../../mainWin.cpp" line="661"/>
         <source>Uncompressed Archive</source>
         <translation>Archivio Non Compresso</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="636"/>
-        <location filename="../../mainWin.cpp" line="660"/>
+        <location filename="../../mainWin.cpp" line="638"/>
+        <location filename="../../mainWin.cpp" line="662"/>
         <source>GZip Compressed Archive</source>
         <translation>Archivio Compresso GZip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="637"/>
-        <location filename="../../mainWin.cpp" line="661"/>
-        <location filename="../../mainWin.cpp" line="662"/>
+        <location filename="../../mainWin.cpp" line="639"/>
+        <location filename="../../mainWin.cpp" line="663"/>
+        <location filename="../../mainWin.cpp" line="664"/>
         <source>BZip Compressed Archive</source>
         <translation>Archivio Compresso BZip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="638"/>
-        <location filename="../../mainWin.cpp" line="663"/>
+        <location filename="../../mainWin.cpp" line="640"/>
+        <location filename="../../mainWin.cpp" line="665"/>
         <source>BZip2 Compressed Archive</source>
         <translation>Archivio Compresso BZip2</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="639"/>
-        <location filename="../../mainWin.cpp" line="671"/>
+        <location filename="../../mainWin.cpp" line="641"/>
+        <location filename="../../mainWin.cpp" line="673"/>
         <source>LMZA Compressed Archive</source>
         <translation>Archivio Compresso LZMA</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="640"/>
-        <location filename="../../mainWin.cpp" line="668"/>
+        <location filename="../../mainWin.cpp" line="642"/>
+        <location filename="../../mainWin.cpp" line="670"/>
         <source>XZ Compressed Archive</source>
         <translation>Archivio Compresso XZ</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="641"/>
-        <location filename="../../mainWin.cpp" line="672"/>
+        <location filename="../../mainWin.cpp" line="643"/>
+        <location filename="../../mainWin.cpp" line="674"/>
         <source>Zstandard Compressed Archive</source>
         <translation>Archivio Compresso Zstandard</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="642"/>
-        <location filename="../../mainWin.cpp" line="674"/>
+        <location filename="../../mainWin.cpp" line="644"/>
+        <location filename="../../mainWin.cpp" line="676"/>
         <source>CPIO Archive</source>
         <translation>Archivio CPIO</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="644"/>
-        <location filename="../../mainWin.cpp" line="676"/>
+        <location filename="../../mainWin.cpp" line="646"/>
+        <location filename="../../mainWin.cpp" line="678"/>
         <source>AR Archive</source>
         <translation>Archivio AR</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="646"/>
-        <location filename="../../mainWin.cpp" line="678"/>
+        <location filename="../../mainWin.cpp" line="648"/>
+        <location filename="../../mainWin.cpp" line="680"/>
         <source>Zip Archive</source>
         <translation>Archivio Zip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="647"/>
-        <location filename="../../mainWin.cpp" line="680"/>
+        <location filename="../../mainWin.cpp" line="649"/>
+        <location filename="../../mainWin.cpp" line="682"/>
         <source>Gzip Archive</source>
         <translation>Archivio Gzip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="648"/>
-        <location filename="../../mainWin.cpp" line="679"/>
+        <location filename="../../mainWin.cpp" line="650"/>
+        <location filename="../../mainWin.cpp" line="681"/>
         <source>7-Zip Archive</source>
         <translation>Archivio 7-Zip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="664"/>
-        <location filename="../../mainWin.cpp" line="665"/>
+        <location filename="../../mainWin.cpp" line="666"/>
+        <location filename="../../mainWin.cpp" line="667"/>
         <source>READ-ONLY: BZip Archive</source>
         <translation>SOLA-LETTURA: Archivio BZip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="666"/>
+        <location filename="../../mainWin.cpp" line="668"/>
         <source>READ-ONLY: BZip2 Archive</source>
         <translation>SOLA-LETTURA: Archivio BZip2</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="667"/>
+        <location filename="../../mainWin.cpp" line="669"/>
         <source>READ-ONLY: BZip2 Compressed PDF Document</source>
         <translation>SOLA-LETTURA: Documento PDF Compresso BZip2</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="669"/>
+        <location filename="../../mainWin.cpp" line="671"/>
         <source>READ-ONLY: XZ archive</source>
         <translation>SOLA-LETTURA: Archivio XZ</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="670"/>
+        <location filename="../../mainWin.cpp" line="672"/>
         <source>READ-ONLY: XZ Compressed PDF Document</source>
         <translation>SOLA-LETTURA: Documento PDF Compresso XZ</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="673"/>
+        <location filename="../../mainWin.cpp" line="675"/>
         <source>READ-ONLY: Zstandard archive</source>
         <translation>SOLA-LETTURA: Archivio Zstandard</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="681"/>
+        <location filename="../../mainWin.cpp" line="683"/>
         <source>Gzip Compressed PDF Document</source>
         <translation>Documento PDF Compresso Gzip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="682"/>
+        <location filename="../../mainWin.cpp" line="684"/>
         <source>READ-ONLY: Compressed SVG Image</source>
         <translation>SOLA-LETTURA: Immagine SVG Compressa</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="683"/>
-        <location filename="../../mainWin.cpp" line="684"/>
         <location filename="../../mainWin.cpp" line="685"/>
         <location filename="../../mainWin.cpp" line="686"/>
+        <location filename="../../mainWin.cpp" line="687"/>
+        <location filename="../../mainWin.cpp" line="688"/>
         <source>READ-ONLY: ISO Image</source>
         <translation>SOLA-LETTURA: Immagine ISO</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="687"/>
+        <location filename="../../mainWin.cpp" line="689"/>
         <source>READ-ONLY: XAR Archive</source>
         <translation>SOLA-LETTURA: Archivio XAR</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="688"/>
+        <location filename="../../mainWin.cpp" line="690"/>
         <source>READ-ONLY: Java Archive</source>
         <translation>SOLA-LETTURA: Archivio Java</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="689"/>
+        <location filename="../../mainWin.cpp" line="691"/>
         <source>READ-ONLY: Debian Package</source>
         <translation>SOLA-LETTURA: Pacchetto Debian</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="690"/>
-        <location filename="../../mainWin.cpp" line="691"/>
+        <location filename="../../mainWin.cpp" line="692"/>
+        <location filename="../../mainWin.cpp" line="693"/>
         <source>READ-ONLY: RedHat Package</source>
         <translation>SOLA-LETTURA: Pacchetto RedHat</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="692"/>
-        <location filename="../../mainWin.cpp" line="693"/>
         <location filename="../../mainWin.cpp" line="694"/>
+        <location filename="../../mainWin.cpp" line="695"/>
+        <location filename="../../mainWin.cpp" line="696"/>
         <source>READ-ONLY: MS Windows Executable</source>
         <translation>SOLA-LETTURA: Eseguibile MS Windows</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="695"/>
+        <location filename="../../mainWin.cpp" line="697"/>
         <source>READ-ONLY: MS Windows Installer Package</source>
         <translation>SOLA-LETTURA: Pacchetto Installazione MS Windows</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="696"/>
+        <location filename="../../mainWin.cpp" line="698"/>
         <source>READ-ONLY: MS Windows Cabinet Archive</source>
         <translation>SOLA-LETTURA: Archivio Cabinet MS Windows</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="697"/>
-        <source>READ-ONLY: ACE archive</source>
-        <translation>SOLA-LETTURA: Archivio ACE</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="698"/>
+        <location filename="../../mainWin.cpp" line="700"/>
         <source>READ-ONLY: Android Package</source>
         <translation>SOLA-LETTURA: Pacchetto Android</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="699"/>
+        <location filename="../../mainWin.cpp" line="701"/>
         <source>READ-ONLY: RAR Archive</source>
         <translation>SOLA-LETTURA: Archivio RAR</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="700"/>
+        <location filename="../../mainWin.cpp" line="702"/>
         <source>READ-ONLY: AppImage application bundle</source>
         <translation>SOLO IN LETTURA: Bundle Appimage</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="701"/>
+        <location filename="../../mainWin.cpp" line="703"/>
         <source>READ-ONLY: VirtualBox Extension Pack</source>
         <translation>SOLA LETTURA: Pacchetto di estensioni VirtualBox</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="710"/>
+        <location filename="../../mainWin.cpp" line="712"/>
         <source>All Known Types</source>
         <translation>Tutti I Tipi</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="715"/>
+        <location filename="../../mainWin.cpp" line="717"/>
         <source>Show All Files</source>
         <translation>Mostra Tutti I File</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1064"/>
+        <location filename="../../mainWin.cpp" line="1066"/>
         <source>Open Containing Folder</source>
         <translation>Apri Cartella Contentente</translation>
     </message>
@@ -612,39 +607,39 @@ l&apos;eseguibile non è incluso in libarchive.</translation>
         <translation>Mostra Elemento Corrente</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1109"/>
-        <location filename="../../mainWin.cpp" line="1117"/>
+        <location filename="../../mainWin.cpp" line="1111"/>
+        <location filename="../../mainWin.cpp" line="1119"/>
         <source>Enter Password</source>
         <translation>Inserisci Password</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1125"/>
+        <location filename="../../mainWin.cpp" line="1127"/>
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1130"/>
+        <location filename="../../mainWin.cpp" line="1132"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1134"/>
+        <location filename="../../mainWin.cpp" line="1136"/>
         <source>Encrypt the file list</source>
         <translation>Cripta l&apos;elenco dei file</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1135"/>
+        <location filename="../../mainWin.cpp" line="1137"/>
         <source>This will take effect after files/folders are added.</source>
         <translation>Ciò avrà effetto dopo l&apos;aggiunta dei file/cartelle.</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1206"/>
-        <location filename="../../mainWin.cpp" line="1282"/>
+        <location filename="../../mainWin.cpp" line="1208"/>
+        <location filename="../../mainWin.cpp" line="1284"/>
         <source>Extract Into Directory</source>
         <translation>Estrai Nella Directory</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1300"/>
+        <location filename="../../mainWin.cpp" line="1301"/>
         <source>Some files will be overwritten.
 Do you want to continue?
 </source>
@@ -653,43 +648,43 @@ Vuoi continuare?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1426"/>
+        <location filename="../../mainWin.cpp" line="1427"/>
         <source>Link To: %1</source>
         <translation>Collegamento A: %1</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1696"/>
+        <location filename="../../mainWin.cpp" line="1694"/>
         <source>Could not read archive</source>
         <translation>Impossibile leggere l&apos;archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1769"/>
+        <location filename="../../mainWin.cpp" line="1765"/>
         <source>A simple Qt archive manager</source>
         <translation>Un semplice gestore di archivi in Qt</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1770"/>
+        <location filename="../../mainWin.cpp" line="1766"/>
         <source>based on libarchive, gzip and 7z</source>
         <translation>basato su libarchive, gzip e 7z</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1771"/>
+        <location filename="../../mainWin.cpp" line="1767"/>
         <source>Author</source>
         <translation>Autore</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1772"/>
+        <location filename="../../mainWin.cpp" line="1768"/>
         <source>aka.</source>
         <translation>alias</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1773"/>
-        <location filename="../../mainWin.cpp" line="1774"/>
+        <location filename="../../mainWin.cpp" line="1769"/>
+        <location filename="../../mainWin.cpp" line="1770"/>
         <source>About Arqiver</source>
         <translation>Informazioni su Arqiver</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1773"/>
+        <location filename="../../mainWin.cpp" line="1769"/>
         <source>Translators</source>
         <translation>Traduttori</translation>
     </message>
