@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2018-2024 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2018-2025 <tsujan2000@gmail.com>
  *
  * Arqiver is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -44,6 +44,8 @@
 #include <QStandardPaths>
 
 #include <unistd.h> // getuid
+#include <algorithm>
+#include <cmath>
 
 namespace Arqiver {
 
@@ -112,7 +114,7 @@ QPixmap TreeWidgetItem::emblemizedPixmap(const QString iconName, const QSize& ic
     }
     else
       emblem = QIcon(":icons/emblem-symbolic-link.svg").pixmap(emblemSize, emblemSize);
-    qreal pixelRatio = icn.devicePixelRatio();
+    double pixelRatio = icn.devicePixelRatio();
     pix = QPixmap((QSizeF(icnSize) * pixelRatio).toSize());
     pix.fill(Qt::transparent);
     pix.setDevicePixelRatio(pixelRatio);
@@ -155,7 +157,7 @@ mainWin::mainWin() : QMainWindow(), ui(new Ui::mainWin) {
   textLabel_->setFocusPolicy(Qt::NoFocus);
   statusProgress_ = new QProgressBar();
   statusProgress_->setTextVisible(false);
-  statusProgress_->setMaximumHeight(qMax(QFontMetrics(font()).height(), 16));
+  statusProgress_->setMaximumHeight(std::max(QFontMetrics(font()).height(), 16));
   statusProgress_->setFocusPolicy(Qt::NoFocus);
   statusProgress_->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
   ui->statusbar->addWidget(iconLabel_);
@@ -694,7 +696,7 @@ QHash<QString, QString> mainWin::supportedMimeTypes() {
     supported.insert ("application/x-msdownload", tr("READ-ONLY: MS Windows Executable") + " (*.exe *.com)");
     supported.insert ("application/x-msi", tr("READ-ONLY: MS Windows Installer Package") + " (*.msi)");
     supported.insert ("application/vnd.ms-cab-compressed", tr("READ-ONLY: MS Windows Cabinet Archive") + " (*.cab)");
-    supported.insert ("application/x-ace", tr("READ-ONLY: ACE archive") + " (*.ace)");
+    //supported.insert ("application/x-ace", tr("READ-ONLY: ACE archive") + " (*.ace)");
     supported.insert ("application/vnd.android.package-archive", tr("READ-ONLY: Android Package") + " (*.apk)");
     supported.insert ("application/vnd.rar", tr("READ-ONLY: RAR Archive") + " (*.rar)");
     supported.insert ("application/vnd.appimage", tr("READ-ONLY: AppImage application bundle") + " (*.appimage)");
@@ -707,7 +709,7 @@ QString mainWin::openingTypes() {
   static QString fileTypes;
   if (fileTypes.isEmpty()) {
     QStringList types;
-    types << tr("All Known Types") + " (*.tar.gz *.tar.xz *.xz *.tar.bz *.tar.bz2 *.bz *.bz2 *.tar.lzma *.tar.zst *.zst *.tar *.zip *.tgz *.txz *.tzst *.tbz *.tbz2 *.tlz *.cpio *.ar *.7z *.gz *.svgz *.iso *.img *.xar *.jar *.deb *.rpm *.exe *.com *.msi *.cab *.ace *.apk *.rar *.appimage *.vbox-extpack *.dmg)";
+    types << tr("All Known Types") + " (*.tar.gz *.tar.xz *.xz *.tar.bz *.tar.bz2 *.bz *.bz2 *.tar.lzma *.tar.zst *.zst *.tar *.zip *.tgz *.txz *.tzst *.tbz *.tbz2 *.tlz *.cpio *.ar *.7z *.gz *.svgz *.iso *.img *.xar *.jar *.deb *.rpm *.exe *.com *.msi *.cab *.apk *.rar *.appimage *.vbox-extpack *.dmg)";
     QStringList l = supportedMimeTypes().values();
     l.removeDuplicates();
     l.sort();
@@ -1163,23 +1165,23 @@ bool mainWin::pswrdDialog(bool listEncryptionBox, bool forceListEncryption) {
 
   bool res = true;
   switch (dialog->exec()) {
-  case QDialog::Accepted:
-    if (lineEdit->text().isEmpty())
+    case QDialog::Accepted:
+      if (lineEdit->text().isEmpty())
+        res = false;
+      else {
+        BACKEND->setPswrd(lineEdit->text());
+        if (box->isChecked())
+          BACKEND->encryptFileList();
+        if (listEncryptionBox)
+          lastPswrd_ = lineEdit->text();
+      }
+      delete dialog;
+      break;
+    case QDialog::Rejected:
+    default:
+      delete dialog;
       res = false;
-    else {
-      BACKEND->setPswrd(lineEdit->text());
-      if (box->isChecked())
-        BACKEND->encryptFileList();
-      if (listEncryptionBox)
-        lastPswrd_ = lineEdit->text();
-    }
-    delete dialog;
-    break;
-  case QDialog::Rejected:
-  default:
-    delete dialog;
-    res = false;
-    break;
+      break;
   }
 
   if (!res) { // don't proceed with autoextraction
@@ -1286,8 +1288,7 @@ void mainWin::extractSelection() {
   bool overwrite(false);
   if (!selList.isEmpty()) {
     selList.sort();
-    for (const auto &file : std::as_const(selList))
-    {
+    for (const auto &file : std::as_const(selList)) {
         /* the path may contain newlines, which have been escaped and are restored here */
         QString realFile(file);
         realFile.replace(QRegularExpression("(?<!\\\\)\\\\n"), "\n")
@@ -1356,15 +1357,15 @@ void mainWin::onEnterPressed(QTreeWidgetItem *it) {
   else viewFile(it);
 }
 
-static inline QString displaySize(const qint64 size) {
-  static const QStringList labels = {"B", "K", "M", "G", "T"};
+static inline QString displaySize(const qint64 size, const QLocale &l) {
+  static const QStringList sizeUnits = {" B", " K", " M", " G", " T"};
   int i = 0;
-  qreal displaySize = size;
-  while (displaySize > static_cast<qreal>(1024) && i < 4) {
-    displaySize /= static_cast<qreal>(1024);
+  double displaySize = size;
+  while (displaySize > static_cast<double>(1024) && i < 4) {
+    displaySize /= 1024;
     ++i;
   }
-  return (QString::number(qRound(displaySize)) + labels.at(i));
+  return (l.toString(std::round(displaySize * 10) / 10) + sizeUnits.at(i));
 }
 
 void mainWin::updateTree() {
@@ -1377,11 +1378,11 @@ void mainWin::updateTree() {
 
   /* NOTE: With big archives, QHash is much faster than finding items. */
   /* remove items that aren't in the archive and get the remaining items */
-  QHash<QString, QTreeWidgetItem*> allPrevItems = cleanTree(files.size() > 10000 ? QStringList() : files);
+  QHash<QString, QTreeWidgetItem*> allPrevItems = cleanTree(files.size() > 10000 ? QStringList()
+                                                                                 : files);
   QHash<const QString, QTreeWidgetItem*> dirs; // keep track of directory items
 
-  for (const auto& thisFile : std::as_const(files))
-  {
+  for (const auto& thisFile : std::as_const(files)) {
     QTreeWidgetItem *item = allPrevItems.value(thisFile);
     if (item != nullptr) { // already in the tree widget
       if (BACKEND->isDir(thisFile))
@@ -1410,12 +1411,12 @@ void mainWin::updateTree() {
         if (s <= static_cast<double>(0) && files.size() == 1) { // as with "application/x-bzip"
           auto cs = BACKEND->csize(thisFile);
           if (cs > static_cast<double>(0))
-            it->setText(2, "≥ " + displaySize(cs));
+            it->setText(2, "≥ " + displaySize(cs, locale()));
           else
-            it->setText(2, displaySize(s));
+            it->setText(2, displaySize(s, locale()));
         }
         else
-          it->setText(2, displaySize(s));
+          it->setText(2, displaySize(s, locale()));
 
         if (icnSize.width() > 16 && BACKEND->isEncryptedPath(thisFile))
           it->setData(3, Qt::UserRole, "lock"); // to be used in TreeWidgetItem::data() and cleanTree()
@@ -1447,8 +1448,7 @@ void mainWin::updateTree() {
           sections.removeLast();
           QTreeWidgetItem *parentItem = nullptr;
           QString theFile;
-          for (const auto& thisSection : std::as_const(sections))
-          {
+          for (const auto& thisSection : std::as_const(sections)) {
             theFile += (theFile.isEmpty() ? QString() : "/") + thisSection;
             QTreeWidgetItem *thisParent = dirs.value(theFile);
             if (!thisParent) {
@@ -1609,8 +1609,7 @@ void mainWin::procFinished(bool success, const QString& msg) {
 
   QTreeWidgetItem *cur = ui->tree_contents->currentItem();
   bool curSelected = false;
-  if (cur && ui->tree_contents->selectedItems().contains(cur))
-  {
+  if (cur && ui->tree_contents->selectedItems().contains(cur)) {
     curSelected = true;
     textLabel_->setText(cur->whatsThis(0).replace('\n', ' ').replace('\t', ' '));
   }
@@ -1661,8 +1660,7 @@ void mainWin::procFinished(bool success, const QString& msg) {
   }
 
   if (!(updateTree_ && success) // otherwise, the cursor will be restored in updateTree()
-      && QGuiApplication::overrideCursor() != nullptr)
-  {
+      && QGuiApplication::overrideCursor() != nullptr) {
     QGuiApplication::restoreOverrideCursor();
   }
 
@@ -1705,13 +1703,11 @@ void mainWin::selectionChanged() {
   ui->actionExtractSel->setEnabled(hasSelection);
   ui->actionRemoveFile->setEnabled(hasSelection && canModify_ && !BACKEND->isGzip());
   QTreeWidgetItem *cur = ui->tree_contents->currentItem();
-  if (cur && ui->tree_contents->selectedItems().contains(cur))
-  {
+  if (cur && ui->tree_contents->selectedItems().contains(cur)) {
     ui->actionView->setEnabled(!cur->text(1).isEmpty());
     textLabel_->setText(cur->whatsThis(0).replace('\n', ' ').replace('\t', ' '));
   }
-  else
-  {
+  else {
     ui->actionView->setEnabled(false);
     textLabel_->setText(lastMsg_);
   }
@@ -1726,10 +1722,10 @@ void mainWin::adjustColumnSizes() {
     ui->tree_contents->resizeColumnToContents(1);
   });
   QTimer::singleShot(0, this, [this]() {
-    ui->tree_contents->setColumnWidth(0, qMax(ui->tree_contents->getSizeHintForColumn(0),
-                                              ui->tree_contents->viewport()->width()
-                                                - ui->tree_contents->columnWidth(1)
-                                                - ui->tree_contents->columnWidth(2)));
+    ui->tree_contents->setColumnWidth(0, std::max(ui->tree_contents->getSizeHintForColumn(0),
+                                                  ui->tree_contents->viewport()->width()
+                                                    - ui->tree_contents->columnWidth(1)
+                                                    - ui->tree_contents->columnWidth(2)));
   });
 }
 
